.. toctree::
   :maxdepth: 2

pyramid_fullauth!
=================

From here You can learn how to use and customize this plugin.


Contents
--------

.. toctree::
   :maxdepth: 2

   basic
   advanced
   social
   narrative
   customise
   api


Contributions:
==============

Before the plugin has been made published outside of RedSky, it gained contributions from these people:

- Agnieszka Głąbała:
    - Social login/registration
    - email change
- Andrzej Bistram
    - tests for social login/registration
- Veronica Zgirvaci
    - registration improvements and fixes
    - documentation improvements
- Tomasz Święcicki
    - various social login/registration fixes

If I omitted anyone else, please let me know, so I could extend it.
